Welcome to PyEHM's documentation!
=================================
PyEHM is an open-source python package that includes implementations of the Efficient Hypothesis Management (EHM)
Algorithms described in [EHM1]_, [EHM2]_ and **covered by the patent** [EHMPAT]_.

.. [EHM1] Maskell, S., Briers, M. and Wright, R., 2004, August. Fast mutual exclusion. In Signal and Data Processing
    of Small Targets 2004 (Vol. 5428, pp. 526-536). International Society for Optics and Photonics
.. [EHM2] Horridge, P. and Maskell, S., 2006, July. Real-time tracking of hundreds of targets with efficient exact
    JPDAF implementation. In 2006 9th International Conference on Information Fusion (pp. 1-8). IEEE
.. [EHMPAT] Maskell, S., 2003, July. Signal Processing with Reduced Combinatorial Complexity. Patent Reference:0315349.1


.. toctree::
    :hidden:
    :maxdepth: 2

    install
    reference
    auto_examples/index
    license
